Crate semaphore_rs_witness

Crate semaphore_rs_witness 

Modules

graph

Structs

Graph
HashSignalInfo

Functions

calculate_witness
Calculate witness based on serialized graph and inputs
get_input_mapping
Calculates the position of the given signal in the inputs buffer
get_inputs_buffer
Allocates inputs vec with position 0 set to 1
get_inputs_size
Calculates the number of needed inputs
init_graph
Loads the graph from bytes
populate_inputs
Sets all provided inputs given the mapping and inputs buffer